# RmediatoR: Request Mediator

<div style="text-align: center;">
<img src="./docs/images/RmediatoR.png" width="200" height="200">
<p align="left">
  <a href="#introduction">Introduction</a> •
  <a href="#demonstration">Demonstration</a> •
  <a href="#how-to-use">How to Use</a> •
</p>
</div>

## [Introduction](#introduction)

RmediatoR is a request mediator that allows you to make requests to multiple APIs at once. It is a simple and easy-to-use tool that allows you to make requests to multiple APIs at once, and then process the responses in a single place. It is a simple and easy-to-use tool that allows you to make requests to multiple APIs at once, and then process the responses in a single place.

## [Demonstration](#demonstration)

--- Under construction ---

## [How to Use](#how-to-use)

--- Under construction ---
